@@ -8,10 +8,8 @@ import pkgutil
 import pkg_resources  # part of setuptools
 version = pkg_resources.require("pbn2html")[0].version
 
-if "pbn2html" in os.environ.get("_"):
-    from .pbn_parser import importPBN
-else:
-    from pbn_parser import importPBN
+from .pbn_parser import importPBN
+
 from string import Template
 
 language="Chinese"
